# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ServerScopeArgs', 'ServerScope']

@pulumi.input_type
class ServerScopeArgs:
    def __init__(__self__, *,
                 auth_server_id: pulumi.Input[builtins.str],
                 consent: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 metadata_publish: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 optional: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a ServerScope resource.
        :param pulumi.Input[builtins.str] auth_server_id: Auth server ID
        :param pulumi.Input[builtins.str] consent: Indicates whether a consent dialog is needed for the scope. It can be set to `REQUIRED` or `IMPLICIT`. Default: `IMPLICIT`
        :param pulumi.Input[builtins.bool] default: A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        :param pulumi.Input[builtins.str] description: Description of the Auth Server Scope.
        :param pulumi.Input[builtins.str] display_name: Name of the end user displayed in a consent dialog box
        :param pulumi.Input[builtins.str] metadata_publish: Whether to publish metadata or not. It can be set to `ALL_CLIENTS` or `NO_CLIENTS`. Default: `ALL_CLIENTS`
        :param pulumi.Input[builtins.str] name: Auth server scope name
        :param pulumi.Input[builtins.bool] optional: Whether the scope optional
        """
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        if consent is not None:
            pulumi.set(__self__, "consent", consent)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if metadata_publish is not None:
            pulumi.set(__self__, "metadata_publish", metadata_publish)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if optional is not None:
            pulumi.set(__self__, "optional", optional)

    @property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Input[builtins.str]:
        """
        Auth server ID
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "auth_server_id", value)

    @property
    @pulumi.getter
    def consent(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether a consent dialog is needed for the scope. It can be set to `REQUIRED` or `IMPLICIT`. Default: `IMPLICIT`
        """
        return pulumi.get(self, "consent")

    @consent.setter
    def consent(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consent", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the Auth Server Scope.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the end user displayed in a consent dialog box
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="metadataPublish")
    def metadata_publish(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to publish metadata or not. It can be set to `ALL_CLIENTS` or `NO_CLIENTS`. Default: `ALL_CLIENTS`
        """
        return pulumi.get(self, "metadata_publish")

    @metadata_publish.setter
    def metadata_publish(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "metadata_publish", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Auth server scope name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def optional(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the scope optional
        """
        return pulumi.get(self, "optional")

    @optional.setter
    def optional(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "optional", value)


@pulumi.input_type
class _ServerScopeState:
    def __init__(__self__, *,
                 auth_server_id: Optional[pulumi.Input[builtins.str]] = None,
                 consent: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 metadata_publish: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 optional: Optional[pulumi.Input[builtins.bool]] = None,
                 system: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ServerScope resources.
        :param pulumi.Input[builtins.str] auth_server_id: Auth server ID
        :param pulumi.Input[builtins.str] consent: Indicates whether a consent dialog is needed for the scope. It can be set to `REQUIRED` or `IMPLICIT`. Default: `IMPLICIT`
        :param pulumi.Input[builtins.bool] default: A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        :param pulumi.Input[builtins.str] description: Description of the Auth Server Scope.
        :param pulumi.Input[builtins.str] display_name: Name of the end user displayed in a consent dialog box
        :param pulumi.Input[builtins.str] metadata_publish: Whether to publish metadata or not. It can be set to `ALL_CLIENTS` or `NO_CLIENTS`. Default: `ALL_CLIENTS`
        :param pulumi.Input[builtins.str] name: Auth server scope name
        :param pulumi.Input[builtins.bool] optional: Whether the scope optional
        :param pulumi.Input[builtins.bool] system: Whether Okta created the Scope
        """
        if auth_server_id is not None:
            pulumi.set(__self__, "auth_server_id", auth_server_id)
        if consent is not None:
            pulumi.set(__self__, "consent", consent)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if metadata_publish is not None:
            pulumi.set(__self__, "metadata_publish", metadata_publish)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if optional is not None:
            pulumi.set(__self__, "optional", optional)
        if system is not None:
            pulumi.set(__self__, "system", system)

    @property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Auth server ID
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auth_server_id", value)

    @property
    @pulumi.getter
    def consent(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether a consent dialog is needed for the scope. It can be set to `REQUIRED` or `IMPLICIT`. Default: `IMPLICIT`
        """
        return pulumi.get(self, "consent")

    @consent.setter
    def consent(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consent", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the Auth Server Scope.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the end user displayed in a consent dialog box
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="metadataPublish")
    def metadata_publish(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to publish metadata or not. It can be set to `ALL_CLIENTS` or `NO_CLIENTS`. Default: `ALL_CLIENTS`
        """
        return pulumi.get(self, "metadata_publish")

    @metadata_publish.setter
    def metadata_publish(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "metadata_publish", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Auth server scope name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def optional(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the scope optional
        """
        return pulumi.get(self, "optional")

    @optional.setter
    def optional(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "optional", value)

    @property
    @pulumi.getter
    def system(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether Okta created the Scope
        """
        return pulumi.get(self, "system")

    @system.setter
    def system(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "system", value)


@pulumi.type_token("okta:auth/serverScope:ServerScope")
class ServerScope(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_server_id: Optional[pulumi.Input[builtins.str]] = None,
                 consent: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 metadata_publish: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 optional: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        Creates an Authorization Server Scope. This resource allows you to create and configure an Authorization Server Scope.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.auth.ServerScope("example",
            auth_server_id="<auth server id>",
            metadata_publish="NO_CLIENTS",
            name="example",
            consent="IMPLICIT")
        ```

        ## Import

        ```sh
        $ pulumi import okta:auth/serverScope:ServerScope example <auth_server_id>/<scope_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auth_server_id: Auth server ID
        :param pulumi.Input[builtins.str] consent: Indicates whether a consent dialog is needed for the scope. It can be set to `REQUIRED` or `IMPLICIT`. Default: `IMPLICIT`
        :param pulumi.Input[builtins.bool] default: A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        :param pulumi.Input[builtins.str] description: Description of the Auth Server Scope.
        :param pulumi.Input[builtins.str] display_name: Name of the end user displayed in a consent dialog box
        :param pulumi.Input[builtins.str] metadata_publish: Whether to publish metadata or not. It can be set to `ALL_CLIENTS` or `NO_CLIENTS`. Default: `ALL_CLIENTS`
        :param pulumi.Input[builtins.str] name: Auth server scope name
        :param pulumi.Input[builtins.bool] optional: Whether the scope optional
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerScopeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Authorization Server Scope. This resource allows you to create and configure an Authorization Server Scope.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.auth.ServerScope("example",
            auth_server_id="<auth server id>",
            metadata_publish="NO_CLIENTS",
            name="example",
            consent="IMPLICIT")
        ```

        ## Import

        ```sh
        $ pulumi import okta:auth/serverScope:ServerScope example <auth_server_id>/<scope_id>
        ```

        :param str resource_name: The name of the resource.
        :param ServerScopeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerScopeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_server_id: Optional[pulumi.Input[builtins.str]] = None,
                 consent: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 metadata_publish: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 optional: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerScopeArgs.__new__(ServerScopeArgs)

            if auth_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'auth_server_id'")
            __props__.__dict__["auth_server_id"] = auth_server_id
            __props__.__dict__["consent"] = consent
            __props__.__dict__["default"] = default
            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["metadata_publish"] = metadata_publish
            __props__.__dict__["name"] = name
            __props__.__dict__["optional"] = optional
            __props__.__dict__["system"] = None
        super(ServerScope, __self__).__init__(
            'okta:auth/serverScope:ServerScope',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_server_id: Optional[pulumi.Input[builtins.str]] = None,
            consent: Optional[pulumi.Input[builtins.str]] = None,
            default: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            metadata_publish: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            optional: Optional[pulumi.Input[builtins.bool]] = None,
            system: Optional[pulumi.Input[builtins.bool]] = None) -> 'ServerScope':
        """
        Get an existing ServerScope resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auth_server_id: Auth server ID
        :param pulumi.Input[builtins.str] consent: Indicates whether a consent dialog is needed for the scope. It can be set to `REQUIRED` or `IMPLICIT`. Default: `IMPLICIT`
        :param pulumi.Input[builtins.bool] default: A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        :param pulumi.Input[builtins.str] description: Description of the Auth Server Scope.
        :param pulumi.Input[builtins.str] display_name: Name of the end user displayed in a consent dialog box
        :param pulumi.Input[builtins.str] metadata_publish: Whether to publish metadata or not. It can be set to `ALL_CLIENTS` or `NO_CLIENTS`. Default: `ALL_CLIENTS`
        :param pulumi.Input[builtins.str] name: Auth server scope name
        :param pulumi.Input[builtins.bool] optional: Whether the scope optional
        :param pulumi.Input[builtins.bool] system: Whether Okta created the Scope
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerScopeState.__new__(_ServerScopeState)

        __props__.__dict__["auth_server_id"] = auth_server_id
        __props__.__dict__["consent"] = consent
        __props__.__dict__["default"] = default
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["metadata_publish"] = metadata_publish
        __props__.__dict__["name"] = name
        __props__.__dict__["optional"] = optional
        __props__.__dict__["system"] = system
        return ServerScope(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Output[builtins.str]:
        """
        Auth server ID
        """
        return pulumi.get(self, "auth_server_id")

    @property
    @pulumi.getter
    def consent(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Indicates whether a consent dialog is needed for the scope. It can be set to `REQUIRED` or `IMPLICIT`. Default: `IMPLICIT`
        """
        return pulumi.get(self, "consent")

    @property
    @pulumi.getter
    def default(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description of the Auth Server Scope.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Name of the end user displayed in a consent dialog box
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="metadataPublish")
    def metadata_publish(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to publish metadata or not. It can be set to `ALL_CLIENTS` or `NO_CLIENTS`. Default: `ALL_CLIENTS`
        """
        return pulumi.get(self, "metadata_publish")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Auth server scope name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def optional(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether the scope optional
        """
        return pulumi.get(self, "optional")

    @property
    @pulumi.getter
    def system(self) -> pulumi.Output[builtins.bool]:
        """
        Whether Okta created the Scope
        """
        return pulumi.get(self, "system")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetTemplateResult',
    'AwaitableGetTemplateResult',
    'get_template',
    'get_template_output',
]

@pulumi.output_type
class GetTemplateResult:
    """
    A collection of values returned by getTemplate.
    """
    def __init__(__self__, brand_id=None, id=None, links=None, name=None):
        if brand_id and not isinstance(brand_id, str):
            raise TypeError("Expected argument 'brand_id' to be a str")
        pulumi.set(__self__, "brand_id", brand_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, str):
            raise TypeError("Expected argument 'links' to be a str")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> builtins.str:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> builtins.str:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the email template
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the email template
        """
        return pulumi.get(self, "name")


class AwaitableGetTemplateResult(GetTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTemplateResult(
            brand_id=self.brand_id,
            id=self.id,
            links=self.links,
            name=self.name)


def get_template(brand_id: Optional[builtins.str] = None,
                 name: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTemplateResult:
    """
    Get a single Email Template for a Brand belonging to an Okta organization.


    :param builtins.str brand_id: Brand ID
    :param builtins.str name: The name of the email template
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getTemplate:getTemplate', __args__, opts=opts, typ=GetTemplateResult).value

    return AwaitableGetTemplateResult(
        brand_id=pulumi.get(__ret__, 'brand_id'),
        id=pulumi.get(__ret__, 'id'),
        links=pulumi.get(__ret__, 'links'),
        name=pulumi.get(__ret__, 'name'))
def get_template_output(brand_id: Optional[pulumi.Input[builtins.str]] = None,
                        name: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTemplateResult]:
    """
    Get a single Email Template for a Brand belonging to an Okta organization.


    :param builtins.str brand_id: Brand ID
    :param builtins.str name: The name of the email template
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getTemplate:getTemplate', __args__, opts=opts, typ=GetTemplateResult)
    return __ret__.apply(lambda __response__: GetTemplateResult(
        brand_id=pulumi.get(__response__, 'brand_id'),
        id=pulumi.get(__response__, 'id'),
        links=pulumi.get(__response__, 'links'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RateLimitingArgs', 'RateLimiting']

@pulumi.input_type
class RateLimitingArgs:
    def __init__(__self__, *,
                 authorize: pulumi.Input[builtins.str],
                 login: pulumi.Input[builtins.str],
                 communications_enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a RateLimiting resource.
        :param pulumi.Input[builtins.str] authorize: Called during authentication. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        :param pulumi.Input[builtins.str] login: Called when accessing the Okta hosted login page. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        :param pulumi.Input[builtins.bool] communications_enabled: Enable or disable rate limiting communications. By default, it is `true`.
        """
        pulumi.set(__self__, "authorize", authorize)
        pulumi.set(__self__, "login", login)
        if communications_enabled is not None:
            pulumi.set(__self__, "communications_enabled", communications_enabled)

    @property
    @pulumi.getter
    def authorize(self) -> pulumi.Input[builtins.str]:
        """
        Called during authentication. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        return pulumi.get(self, "authorize")

    @authorize.setter
    def authorize(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "authorize", value)

    @property
    @pulumi.getter
    def login(self) -> pulumi.Input[builtins.str]:
        """
        Called when accessing the Okta hosted login page. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter(name="communicationsEnabled")
    def communications_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable or disable rate limiting communications. By default, it is `true`.
        """
        return pulumi.get(self, "communications_enabled")

    @communications_enabled.setter
    def communications_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "communications_enabled", value)


@pulumi.input_type
class _RateLimitingState:
    def __init__(__self__, *,
                 authorize: Optional[pulumi.Input[builtins.str]] = None,
                 communications_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RateLimiting resources.
        :param pulumi.Input[builtins.str] authorize: Called during authentication. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        :param pulumi.Input[builtins.bool] communications_enabled: Enable or disable rate limiting communications. By default, it is `true`.
        :param pulumi.Input[builtins.str] login: Called when accessing the Okta hosted login page. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        if authorize is not None:
            pulumi.set(__self__, "authorize", authorize)
        if communications_enabled is not None:
            pulumi.set(__self__, "communications_enabled", communications_enabled)
        if login is not None:
            pulumi.set(__self__, "login", login)

    @property
    @pulumi.getter
    def authorize(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Called during authentication. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        return pulumi.get(self, "authorize")

    @authorize.setter
    def authorize(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authorize", value)

    @property
    @pulumi.getter(name="communicationsEnabled")
    def communications_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable or disable rate limiting communications. By default, it is `true`.
        """
        return pulumi.get(self, "communications_enabled")

    @communications_enabled.setter
    def communications_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "communications_enabled", value)

    @property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Called when accessing the Okta hosted login page. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login", value)


@pulumi.type_token("okta:index/rateLimiting:RateLimiting")
class RateLimiting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorize: Optional[pulumi.Input[builtins.str]] = None,
                 communications_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages rate limiting.
        This resource allows you to configure the client-based rate limit and rate limiting communications settings.
        > **WARNING:** This resource is available only when using a SSWS API token in the provider config, it is incompatible with OAuth 2.0 authentication.
        **WARNING:** This resource makes use of an internal/private Okta API endpoint that could change without notice rendering this resource inoperable.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimiting("example",
            login="ENFORCE",
            authorize="ENFORCE",
            communications_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimiting:RateLimiting example .
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authorize: Called during authentication. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        :param pulumi.Input[builtins.bool] communications_enabled: Enable or disable rate limiting communications. By default, it is `true`.
        :param pulumi.Input[builtins.str] login: Called when accessing the Okta hosted login page. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RateLimitingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages rate limiting.
        This resource allows you to configure the client-based rate limit and rate limiting communications settings.
        > **WARNING:** This resource is available only when using a SSWS API token in the provider config, it is incompatible with OAuth 2.0 authentication.
        **WARNING:** This resource makes use of an internal/private Okta API endpoint that could change without notice rendering this resource inoperable.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimiting("example",
            login="ENFORCE",
            authorize="ENFORCE",
            communications_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimiting:RateLimiting example .
        ```

        :param str resource_name: The name of the resource.
        :param RateLimitingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RateLimitingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorize: Optional[pulumi.Input[builtins.str]] = None,
                 communications_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RateLimitingArgs.__new__(RateLimitingArgs)

            if authorize is None and not opts.urn:
                raise TypeError("Missing required property 'authorize'")
            __props__.__dict__["authorize"] = authorize
            __props__.__dict__["communications_enabled"] = communications_enabled
            if login is None and not opts.urn:
                raise TypeError("Missing required property 'login'")
            __props__.__dict__["login"] = login
        super(RateLimiting, __self__).__init__(
            'okta:index/rateLimiting:RateLimiting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authorize: Optional[pulumi.Input[builtins.str]] = None,
            communications_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            login: Optional[pulumi.Input[builtins.str]] = None) -> 'RateLimiting':
        """
        Get an existing RateLimiting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authorize: Called during authentication. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        :param pulumi.Input[builtins.bool] communications_enabled: Enable or disable rate limiting communications. By default, it is `true`.
        :param pulumi.Input[builtins.str] login: Called when accessing the Okta hosted login page. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RateLimitingState.__new__(_RateLimitingState)

        __props__.__dict__["authorize"] = authorize
        __props__.__dict__["communications_enabled"] = communications_enabled
        __props__.__dict__["login"] = login
        return RateLimiting(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def authorize(self) -> pulumi.Output[builtins.str]:
        """
        Called during authentication. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        return pulumi.get(self, "authorize")

    @property
    @pulumi.getter(name="communicationsEnabled")
    def communications_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Enable or disable rate limiting communications. By default, it is `true`.
        """
        return pulumi.get(self, "communications_enabled")

    @property
    @pulumi.getter
    def login(self) -> pulumi.Output[builtins.str]:
        """
        Called when accessing the Okta hosted login page. Valid values: `ENFORCE` *(Enforce limit and log per client (recommended))*, `DISABLE` *(Do nothing (not recommended))*, `PREVIEW` *(Log per client)*.
        """
        return pulumi.get(self, "login")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetBrandsResult',
    'AwaitableGetBrandsResult',
    'get_brands',
    'get_brands_output',
]

@pulumi.output_type
class GetBrandsResult:
    """
    A collection of values returned by getBrands.
    """
    def __init__(__self__, brands=None, id=None):
        if brands and not isinstance(brands, list):
            raise TypeError("Expected argument 'brands' to be a list")
        pulumi.set(__self__, "brands", brands)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def brands(self) -> Sequence['outputs.GetBrandsBrandResult']:
        """
        List of `Brand` belonging to the organization
        """
        return pulumi.get(self, "brands")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetBrandsResult(GetBrandsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBrandsResult(
            brands=self.brands,
            id=self.id)


def get_brands(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBrandsResult:
    """
    Get the brands belonging to an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getBrands:getBrands', __args__, opts=opts, typ=GetBrandsResult).value

    return AwaitableGetBrandsResult(
        brands=pulumi.get(__ret__, 'brands'),
        id=pulumi.get(__ret__, 'id'))
def get_brands_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBrandsResult]:
    """
    Get the brands belonging to an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getBrands:getBrands', __args__, opts=opts, typ=GetBrandsResult)
    return __ret__.apply(lambda __response__: GetBrandsResult(
        brands=pulumi.get(__response__, 'brands'),
        id=pulumi.get(__response__, 'id')))
